@@ -1,5 +1,7 @@
 """Format adapter for sql."""
 
+from __future__ import annotations
+
 from typing import Generator, Union
 
 from cli_helpers.tabular_output import TabularOutputFormatter
@@ -20,7 +22,7 @@ formatter: TabularOutputFormatter
 
 def escape_for_sql_statement(value: Union[bytes, str]) -> str:
     if isinstance(value, bytes):
-        return f"X'{value.hex()}'"
+        return f"0x{value.hex()}"
     else:
         return formatter.mycli.sqlexecute.conn.escape(value)
 
