@@ -10,7 +10,7 @@ from typing import Any, Generator, Iterable
 import pymysql
 from pymysql.connections import Connection
 from pymysql.constants import FIELD_TYPE
-from pymysql.converters import conversions, convert_date, convert_datetime, convert_timedelta, decoders
+from pymysql.converters import conversions, convert_date, convert_datetime, convert_time, decoders
 from pymysql.cursors import Cursor
 
 from mycli.packages.special import iocommands
@@ -99,6 +99,9 @@ class SQLExecute:
     functions_query = '''SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES
     WHERE ROUTINE_TYPE="FUNCTION" AND ROUTINE_SCHEMA = "%s"'''
 
+    procedures_query = '''SELECT ROUTINE_NAME FROM INFORMATION_SCHEMA.ROUTINES
+    WHERE ROUTINE_TYPE="PROCEDURE" AND ROUTINE_SCHEMA = "%s"'''
+
     table_columns_query = """select TABLE_NAME, COLUMN_NAME from information_schema.columns
                                     where table_schema = '%s'
                                     order by table_name,ordinal_position"""
@@ -257,7 +260,7 @@ class SQLExecute:
         conv.update({
             FIELD_TYPE.TIMESTAMP: lambda obj: convert_datetime(obj) or obj,
             FIELD_TYPE.DATETIME: lambda obj: convert_datetime(obj) or obj,
-            FIELD_TYPE.TIME: lambda obj: convert_timedelta(obj) or obj,
+            FIELD_TYPE.TIME: lambda obj: convert_time(obj) or obj,
             FIELD_TYPE.DATE: lambda obj: convert_date(obj) or obj,
         })
 
@@ -452,6 +455,16 @@ class SQLExecute:
             for row in cur:
                 yield row
 
+    def procedures(self) -> Generator[tuple[str, str], None, None]:
+        """Yields tuples of (procedure_name, )"""
+
+        assert isinstance(self.conn, Connection)
+        with self.conn.cursor() as cur:
+            _logger.debug("Procedures Query. sql: %r", self.procedures_query)
+            cur.execute(self.procedures_query % self.dbname)
+            for row in cur:
+                yield row
+
     def show_candidates(self) -> Generator[tuple, None, None]:
         assert isinstance(self.conn, Connection)
         with self.conn.cursor() as cur:
