@@ -40,6 +40,20 @@ CLI_ARGS = [
 ]
 
 
+@dbtest
+def test_select_from_empty_table(executor):
+    run(executor, """create table t1(id int)""")
+    sql = "select * from t1"
+    runner = CliRunner()
+    result = runner.invoke(cli, args=CLI_ARGS + ["-t"], input=sql)
+    expected = dedent("""\
+        +----+
+        | id |
+        +----+
+        +----+""")
+    assert expected in result.output
+
+
 def test_is_valid_connection_scheme_valid(executor, capsys):
     is_valid, scheme = is_valid_connection_scheme("mysql://test@localhost:3306/dev")
     assert is_valid
@@ -346,6 +360,42 @@ def test_execute_arg(executor):
     assert expected in result.output
 
 
+@dbtest
+def test_execute_arg_with_checkpoint(executor):
+    run(executor, "create table test (a text)")
+    run(executor, 'insert into test values("abc")')
+
+    sql = "select * from test;"
+    runner = CliRunner()
+
+    with NamedTemporaryFile(mode="w", delete=False) as checkpoint:
+        checkpoint.close()
+
+    result = runner.invoke(cli, args=CLI_ARGS + ["--execute", sql, f"--checkpoint={checkpoint.name}"])
+    assert result.exit_code == 0
+
+    with open(checkpoint.name, 'r') as f:
+        contents = f.read()
+    assert sql in contents
+    os.remove(checkpoint.name)
+
+    sql = 'select 10 from nonexistent_table;'
+    result = runner.invoke(cli, args=CLI_ARGS + ["--execute", sql, f"--checkpoint={checkpoint.name}"])
+    assert result.exit_code != 0
+
+    with open(checkpoint.name, 'r') as f:
+        contents = f.read()
+    assert sql not in contents
+
+    # delete=False means we should try to clean up
+    # we don't really need "try" here as open() would have already failed
+    try:
+        if os.path.exists(checkpoint.name):
+            os.remove(checkpoint.name)
+    except Exception as e:
+        print(f"An error occurred while attempting to delete the file: {e}")
+
+
 @dbtest
 def test_execute_arg_with_table(executor):
     run(executor, "create table test (a text)")
@@ -402,7 +452,7 @@ def test_batch_mode_table(executor):
         +----------+
         | count(*) |
         +----------+
-        | 3        |
+        |        3 |
         +----------+
         +-----+
         | a   |
