@@ -33,8 +33,12 @@ def completer():
         tables.append((table,))
         columns.extend([(table, col) for col in cols])
 
+    databases = ["test", "test 2"]
+
+    for db in databases:
+        comp.extend_schemata(db)
+    comp.extend_database_names(databases)
     comp.set_dbname("test")
-    comp.extend_schemata("test")
     comp.extend_relations(tables, kind="tables")
     comp.extend_columns(columns, kind="tables")
     comp.extend_enum_values([("orders", "status", ["pending", "shipped"])])
@@ -50,6 +54,16 @@ def complete_event():
     return Mock()
 
 
+def test_use_database_completion(completer, complete_event):
+    text = "USE "
+    position = len(text)
+    result = completer.get_completions(Document(text=text, cursor_position=position), complete_event)
+    assert list(result) == [
+        Completion(text="test", start_position=0),
+        Completion(text="`test 2`", start_position=0),
+    ]
+
+
 def test_special_name_completion(completer, complete_event):
     text = "\\d"
     position = len("\\d")
@@ -101,6 +115,8 @@ def test_table_completion(completer, complete_event):
         Completion(text="time_zone_name", start_position=0),
         Completion(text="time_zone_transition", start_position=0),
         Completion(text="time_zone_transition_type", start_position=0),
+        Completion(text="test", start_position=0),
+        Completion(text="`test 2`", start_position=0),
     ]
 
 
@@ -400,6 +416,8 @@ def test_table_names_after_from(completer, complete_event):
         Completion(text="time_zone_name", start_position=0),
         Completion(text="time_zone_transition", start_position=0),
         Completion(text="time_zone_transition_type", start_position=0),
+        Completion(text="test", start_position=0),
+        Completion(text="`test 2`", start_position=0),
     ]
 
 
@@ -474,6 +492,8 @@ def test_grant_on_suggets_tables_and_schemata(completer, complete_event):
     position = len(text)
     result = list(completer.get_completions(Document(text=text, cursor_position=position), complete_event))
     assert result == [
+        Completion(text="test", start_position=0),
+        Completion(text="`test 2`", start_position=0),
         Completion(text='users', start_position=0),
         Completion(text='orders', start_position=0),
         Completion(text='`select`', start_position=0),
@@ -500,6 +520,13 @@ def test_deleted_keyword_completion(completer, complete_event):
     ]
 
 
+def test_numbers_no_completion(completer, complete_event):
+    text = "SELECT COUNT(1) FROM time_zone WHERE Time_zone_id = 1"
+    position = len("SELECT COUNT(1) FROM time_zone WHERE Time_zone_id = 1")
+    result = list(completer.get_completions(Document(text=text, cursor_position=position), complete_event))
+    assert result == []  # ie not INT1
+
+
 def dummy_list_path(dir_name):
     dirs = {
         "/": [
@@ -537,3 +564,28 @@ def test_file_name_completion(completer, complete_event, text, expected):
     result = list(completer.get_completions(Document(text=text, cursor_position=position), complete_event))
     expected = [Completion(txt, pos) for txt, pos in expected]
     assert result == expected
+
+
+def test_auto_case_heuristic(completer, complete_event):
+    text = "select jon_"
+    position = len("select jon_")
+    result = list(completer.get_completions(Document(text=text, cursor_position=position), complete_event))
+    assert [x.text for x in result] == [
+        'json_table',
+        'json_value',
+        'join',
+        'json',
+    ]
+
+
+def test_create_table_like_completion(completer, complete_event):
+    text = "CREATE TABLE foo LIKE ti"
+    position = len(text)
+    result = list(completer.get_completions(Document(text=text, cursor_position=position), complete_event))
+    assert [x.text for x in result] == [
+        'time_zone',
+        'time_zone_name',
+        'time_zone_transition',
+        'time_zone_leap_second',
+        'time_zone_transition_type',
+    ]
