@@ -16,7 +16,7 @@ PASSWORD = os.getenv("PYTEST_PASSWORD")
 USER = os.getenv("PYTEST_USER", "root")
 HOST = os.getenv("PYTEST_HOST", "localhost")
 PORT = int(os.getenv("PYTEST_PORT", "3306"))
-CHARSET = os.getenv("PYTEST_CHARSET", "utf8")
+CHARSET = os.getenv("PYTEST_CHARSET", "utf8mb4")
 SSH_USER = os.getenv("PYTEST_SSH_USER", None)
 SSH_HOST = os.getenv("PYTEST_SSH_HOST", None)
 SSH_PORT = int(os.getenv("PYTEST_SSH_PORT", "22"))
@@ -51,12 +51,10 @@ def run(executor, sql, rows_as_list=True):
     results = []
 
     for result in executor.run(sql):
-        (
-            title,
-            rows,
-            headers,
-            status,
-        ) = result.get_output()
+        title = result.title
+        rows = result.results
+        headers = result.headers
+        status = result.status
         rows = list(rows) if (rows_as_list and rows) else rows
         results.append({"title": title, "rows": rows, "headers": headers, "status": status})
 
